#!/bin/bash

PY_SCRIPT="attach-to-email"
DESKTOP_TEMPLATE="template.desktop"
DESKTOP="attachToEmail.desktop"

function check_environ {
#Check to see if we can coax kde-config into the PATH
echo "Checking for kde-config..."
if [ -z "$(type 'kde-config' 2> /dev/null)" ]; then #Odd way of checking if kde-config is in $PATH
  echo "kde-config not found, checking for \$KDEDIR to compensate..."
  if [ ! -z $KDEDIR ]; then
    export PATH=$PATH:$KDEDIR/bin
  else
    echo "***"
    echo "***$0 cannot figure out where KDE is installed."
    echo "***kde-config is not in \$PATH, and \$KDEDIR is not set."
    echo "***To fix this, manually change \$PATH to add the KDE executables."
    echo "***E.g. export PATH=\$PATH:/opt/kde/bin"
    echo "***It would also be a good idea to add this line to your shell login/profile."
    echo "***"
    echo
    echo "Nothing was installed or removed."
    exit 1
  fi
fi
echo "Okay."
}

function install_all {
#Go ahead and install
echo "Generating $DESKTOP ..."
SED_PREFIX=${PREFIX//\//\\\/} #Replace forward slashes in $PREFIX with \/ so that sed doesn't freak out
sed "s/SCRIPT_PATH/$SED_PREFIX\\/bin\\/attach-to-email/" $DESKTOP_TEMPLATE > $DESKTOP
cp -f $DESKTOP $PREFIX/share/apps/konqueror/servicemenus/attachToEmail.desktop
cp -f $PY_SCRIPT $PREFIX/bin/
echo "Making sure to set proper permissions ..."
chmod 0644 $PREFIX/share/apps/konqueror/servicemenus/attachToEmail.desktop
chmod 0755 $PREFIX/bin/$PY_SCRIPT
#Install all i18n stuff
echo "Beginning i18n setup ..."
for i in locale/*; do
  echo "Now installing $i ..."
  if [ ! -d $PREFIX/share/$i/LC_MESSAGES ]; then
    echo "Creating directory $PREFIX/share/$i/LC_MESSAGES/"
    mkdir -p $PREFIX/share/$i/LC_MESSAGES
  fi
  echo "Copying .mo files..."
  cp $i/*.mo $PREFIX/share/$i/LC_MESSAGES/
done
echo "Finished i18n setup."
}

case $1 in
  "--global-install" )
    check_environ
    PREFIX=$(kde-config --prefix)
    echo "Installing in $PREFIX ..."
    if [ "$(id -u)" != "0" ]; then
      echo "You are not root, as would be expected."
      echo "However, we will still attempt a system-wide install."
      echo "But, you might not have permission."
    fi
    install_all
    ;;
  "--local-install" )
    check_environ
    PREFIX=$(kde-config --localprefix)
    echo "Installing in $PREFIX ..."
    if [ ! -d $PREFIX/bin ]; then
      mkdir $PREFIX/bin
    fi
    if [ ! -d $PREFIX/share/apps/konqueror/servicemenus ]; then
      mkdir $PREFIX/share/apps/konqueror/servicemenus
    fi
    install_all
    ;;
  "--remove-old" )
    check_environ
    echo "Attempting to remove old versions."
    if [ "$(id -u)" != "0" ]; then
      echo "You are not root, if you have any global installs, you will probably not have permission to remove them."
    fi
    echo "Removing versions prior to 0.6..."
    rm /usr/local/bin/multiple-attachments-servicemenu
    rm $(kde-config --prefix)/share/apps/konqueror/servicemenus/attachToEmail.desktop
    echo "Removing 0.6 and later versions..."
    rm $(kde-config --prefix)/bin/attach-to-email
    rm $(kde-config --localprefix)/bin/attach-to-email
    rm $(kde-config --localprefix)/share/apps/konqueror/servicemenus/attachToEmail.desktop
    rm attachToEmail.desktop
    echo "Removing extra .mo files from 0.7 and later versions..."
    echo "Beginning i18n setup ..."
    PREFIX=$(kde-config --prefix)
    for i in locale/*; do
      echo "Now removing global $i files ..."
      rm $PREFIX/share/$i/LC_MESSAGES/attach-to-email.mo
    done
    PREFIX=$(kde-config --localprefix)
    for i in locale/*; do
      echo "Now removing local $i files ..."
      rm $PREFIX/share/$i/LC_MESSAGES/attach-to-email.mo
    done
    echo "Done removing old versions."
    exit 0
    ;;
  * )
    echo "Usage: $0 [--global-install|--local-install|--remove-old]"
    echo
    echo "--global-install  attempts a system-wide installation."
    echo "--local-install   attempts to install in your home directory."
    echo "--remove-old      attempts to remove previous installations."
    echo
    exit 0
    ;;
esac

echo "Done."
exit 0
